==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggwidgetprogressbar.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iggwidgetprogressbar.h"


#include "iggframe.h"

#include "ibgwidgetprogressbarsubject.h"

#include "iggsubjectfactory.h"


iggWidgetProgressBar::iggWidgetProgressBar(iggFrame *parent, bool unlaid) : iggWidget(parent)
{
	mSubject = iggSubjectFactory::CreateWidgetProgressBarSubject(this);

	if(unlaid) mWasLaidOut = true;
	mNeedsBaloonHelp = false;
	mAborted = false;
}


iggWidgetProgressBar::~iggWidgetProgressBar()
{
}


void iggWidgetProgressBar::SetLabel(const iString &label)
{
	if(!mAborted) mSubject->SetLabel(label);
}


void iggWidgetProgressBar::SetProgress(int p)
{
	if(!mAborted)
	{
		mSubject->SetProgress(p);
		this->OnSetProgress();
	}
}


void iggWidgetProgressBar::Reset()
{
	mAborted = false;
	mSubject->Reset();
}


bool iggWidgetProgressBar::UpdateWidgetBody()
{
	return true;
}


void iggWidgetProgressBar::Abort()
{
	mAborted = true;
}


void iggWidgetProgressBar::OnSetProgress()
{
	//
	//  Default implementation does nothing
	//
}

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/generic/iggwidgetprogressbar.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iggwidgetprogressbar.h"


#include "iggframe.h"

#include "ibgwidgetprogressbarsubject.h"

#include "iggsubjectfactory.h"


iggWidgetProgressBar::iggWidgetProgressBar(iggFrame *parent, bool unlaid) : iggWidget(parent)
{
	mSubject = iggSubjectFactory::CreateWidgetProgressBarSubject(this);

	if(unlaid) mWasLaidOut = true;
	mNeedsBaloonHelp = false;
	mAborted = false;
}


iggWidgetProgressBar::~iggWidgetProgressBar()
{
}


void iggWidgetProgressBar::SetLabel(const iString &label)
{
	if(!mAborted) mSubject->SetLabel(label);
}


void iggWidgetProgressBar::SetProgress(int p)
{
	if(!mAborted)
	{
		mSubject->SetProgress(p);
		this->OnSetProgress();
	}
}


void iggWidgetProgressBar::Reset()
{
	mAborted = false;
	mSubject->Reset();
}


void iggWidgetProgressBar::UpdateWidgetBody()
{
}


void iggWidgetProgressBar::Abort()
{
	mAborted = true;
}


void iggWidgetProgressBar::OnSetProgress()
{
	//
	//  Default implementation does nothing
	//
}
